#!/usr/bin/env python

import sys


def report(v_thresh, message, indent = 0, is_err = False):
    """Reports the message if verbosity level exceeds the specified threshold."""

    if is_err:
        v_thresh = 0

    if VERBOSITY >= v_thresh:
        if v_thresh <= 2:
            indent = 0

        sys.stderr.write(" " * int(4 * indent) + message + "\n")


def report_options(v_thresh, options, files='', image_list=''):
    """Reports the results of parsing any invocation arguments."""

    if options.verbosity >= v_thresh:

        report = ""

        if image_list:
            report += """\
  IMAGE LIST
 ============
"""
            for image in image_list:
                report += "{0}\t{1}\t{2}\n".format(image[1], image[2], image[0])
            report += "\n"

        if files:
            report += """\
  FILES
 =======
"""
            for filename in files:
                report += "    {0}\n".format(filename)
            report += "\n"

        report += """\
  OPTIONS
 =========

    Application Name (APP_LONG_NAME)    {15}

    (default_duration) / seconds:       {0}
    (default_transition) / seconds:     {1}
    Display time list (specific_durations):
        {2}
    Transition time list (specific_transitions):
        {3}

    Slideshow name (name):              {4}

    Slideshow directory (directory):
        {5}
    Slideshow filename (filename):
        {6}
    Slideshow path (output):
        {7}
    (force_overwrite):                  {8}
    Write to (standard_output):         {9}
    Create files (file_creation)        {14}

    Register wallpaper:                 {17}
    Set wallpaper (set_wallpaper):      {10}
    Send notifications (notify):        {11}

    Display GUI (gui)                   {12}
    Images directory                    {16}

    Verbosity level (verbosity):        {13}

""".format(options.default_duration, options.default_transition, \
        str(options.specific_durations), str(options.specific_transitions), \
        options.name, options.directory, options.filename, options.output, \
        str(options.force_overwrite), str(options.standard_output), \
        str(options.set_wallpaper), str(options.notify), str(options.gui), \
        str(options.verbosity), str(options.file_creation), \
        APP_LONG_NAME, options.images_directory, \
        str(options.register_wallpaper))

        sys.stderr.write(report)

