#!/usr/bin/env python

import gtk

from crebs.times        import get_scaled_duration
from crebs.thumbnails   import get_thumbnail
from crebs.slideshows   import is_slideshow_file, import_slideshow
from crebs.debug        import report


def create_image_list(files, options, indent_offset = 0):
    """Creates the image list from command line arguments."""

    report(2, _("Creating the image list..."), indent_offset)

    image_list = []

    for i in range(len(files)):
        if is_slideshow_file(files[i], True, 2):
            slides = import_slideshow(files[i], 2)

            for slide in slides:
                image_list.append(slide)

        else:
            if not options.gui:
                report(2, _("Adding an image..."), indent_offset + 1)
                report(2, files[i], indent_offset + 2)

            if options.specific_durations[i] < 0:
                duration = options.default_duration
            else:
                duration = options.specific_durations[i]

            if options.specific_transitions[i] < 0:
                transition = options.default_transition
            else:
                transition = options.specific_transitions[i]

            report(3, "Duration: {0}. Transition: {1}.".format(duration, transition), indent_offset + 2)

            image_list.append((files[i], duration, transition))

        report(3, "Success.", indent_offset + 1.5)

    report(3, "Success.", indent_offset + 0.5)

    return image_list


def convert_to_gui_image_list(basic_list, def_duration, def_transition, gui_list = []):
    """Converts a basic image list into a GUI image list."""

    if not gui_list:
        # Image list: filename; icon; use def. dur.; dur./scale; scale; use def. trans.; trans
        gui_list = gtk.ListStore(str, gtk.gdk.Pixbuf, bool, float, int, bool, float)

    for image in basic_list:
        filename   = image[0]
        duration   = image[1]
        transition = image[2]

        icon = get_thumbnail(filename)

        if not icon:
            report(3, "This file is not a valid image.", 1)
            report(3, filename, 2)
        else:
            report(2, _("Adding an image..."), 1)
            report(2, filename, 2)

            if duration == def_duration or duration < 0:
                use_def_dur = True
                duration = def_duration
            else:
                use_def_dur = False

            if transition == def_transition or transition < 0:
                use_def_trn = True
                transition = def_transition
            else:
                use_def_trn = False

            (dur_scaled, scale) = get_scaled_duration(duration)

            gui_list.append((filename, icon, use_def_dur, dur_scaled, scale, use_def_trn, transition))

            report(3, "Success.", 1.5)

    return gui_list


def create_gui_image_list(files, options):
    """Returns the image list used by the GUI, initialised with invocation arguments."""

    # Get any images passed as arguments
    inv_image_list = create_image_list(files, options, 1)

    # Convert to GUI list store
    gui_image_list = convert_to_gui_image_list(inv_image_list, options.default_duration, options.default_transition)

    return gui_image_list



