#!/usr/bin/env python

import os
import gconf

from crebs.entities     import encode_xml_entities
from crebs.debug        import report


def set_wallpaper(s_filename):
    """Sets the slideshow as the wallpaper."""

    report(2, _("Setting slideshow as current background..."))

    success = False
    try:
        client = gconf.client_get_default()
    except:
        report(2, _("Failure: Unable to create gconf client."), 0.5)
    else:
        if not client.set_string("/desktop/gnome/background/picture_filename", s_filename):
            report(2, _("Failure: Unable to set wallpaper with gconf."), 0.5)

        else:
            report(3, "Success.", 0.5)
            success = True

    return success


def read_wallpapers(wp_filename):
    """Reads the user's wallpaper list, and returns the XML contents."""

    report(3, "Reading current wallpaper list...", 1)

    wp_list = ''

    try:
        f = open(wp_filename, 'r')
        try:
            wp_list = f.read()
            report(3, "Success.", 1.5)
        finally:
            f.close()

    except IOError:
        report(3, "Failure: Unable to read from wallpapers file.", 1.5)

    return wp_list


def write_wallpapers(wp_filename, wp_list):
    """Write's the new XML content to the user's wallpaper list."""

    report(3, "Writing new wallpaper list...", 1)

    success = False

    try:
        f = open(wp_filename, 'w')
        try:
            f.write(wp_list)
            success = True
            report(3, "Success.", 1.5)
        finally:
            f.close()

    except IOError:
        report(3, "Failure: Unable to write to wallpapers file.", 1.5)

    return success


def insert_slideshow_xml(s_name, s_filename, wp_list):
    """Appends the new slideshow into the wallpaper-list XML."""

    report(3, "Inserting slideshow into wallpaper list XML...", 1)

    wp_insert = """\
  <wallpaper deleted="false">
    <name>{0}</name>
    <filename>{1}</filename>
    <options>zoom</options>
  </wallpaper>
""".format(encode_xml_entities(s_name), encode_xml_entities(s_filename))

    wp_list = wp_list.replace('</wallpapers>', wp_insert + '</wallpapers>')

    report(3, "Success.", 1.5)

    return wp_list


def register_wallpaper(s_name, s_filename):
    """Inserts the new slideshow into the user's wallpaper list."""

    report(2, _("Registering the slideshow as a wallpaper..."))

    if not s_name:
        s_name = os.path.basename(s_filename)
    report(3, "{0} ({1})".format(s_name, s_filename), 1)

    wp_filename = os.path.join(os.getenv('HOME'), '.gnome2', 'backgrounds.xml')
    success = False

    wp_list = read_wallpapers(wp_filename)

    if not wp_list:
        report(2, _("Failure: The wallpaper list is empty."), 0.5)

    else:
        wp_list = insert_slideshow_xml(s_name, s_filename, wp_list)
        success = write_wallpapers(wp_filename, wp_list)

        if success:
            report(3, "Success.", 0.5)
        else:
            report(2, _("Failure: Unable to register the wallpaper."), 0.5)

    return success
