#!/bin/bash

usage()
{
    cat << EOF
Usage: $0 [[-h]|[-p INSTALLATION_DIRECTORY]? [-v]*]

This script will install Create Background Slideshow, a wallpaper slideshow 
creator for the GNOME desktop, to /usr/local by default, or to the directory 
passed with the -p flag.

OPTIONS:
  -h    Shows this message
  -p    Specifies installation directory
  -v    Be more verbose (use -v -v for extra verbosity)
EOF
}

PREFIX=/usr/local
VERBOSE=

while getopts "hp:v" OPTION
do
    case $OPTION in
        h)
            usage
            exit 1
            ;;
        p)
            PREFIX=$OPTARG
            ;;
        v)
            VERBOSE=$VERBOSE+1
            ;;
        ?)
            usage
            exit
            ;;
    esac
done

## ==== CREATE DIRECTORIES =============================================

if [[ $VERBOSE -ge 1 ]]
then
    echo "Creating required directories..."
fi

LOC_DIR=share/crebs/locale

# Create directories if they don't already exist
for DIR in bin \
           share \
           share/applications \
           share/man \
           share/man/man1 \
           share/crebs \
           share/crebs/glade \
           share/crebs/lib \
           share/crebs/lib/crebs \
           $LOC_DIR
do
    if [[ ! -d $PREFIX/$DIR ]]
    then
        if [[ $VERBOSE -ge 2 ]]
        then
            echo "    $PREFIX/$DIR..."
        fi
        mkdir $PREFIX/$DIR
    fi
done

### Create localisation directories
for LOC in cs cy de en_GB es it lt ro ru uk
do
    if [[ ! -d $PREFIX/$LOC_DIR/$LOC ]]
    then
        if [[ $VERBOSE -ge 2 ]]
        then
            echo "    $PREFIX/$LOC_DIR/$LOC..."
        fi
        mkdir $PREFIX/$LOC_DIR/$LOC
    fi

    if [[ ! -d $PREFIX/$LOC_DIR/$LOC/LC_MESSAGES ]]
    then
        if [[ $VERBOSE -ge 2 ]]
        then
            echo "    $PREFIX/$LOC_DIR/$LOC/LC_MESSAGES..."
        fi
        mkdir $PREFIX/$LOC_DIR/$LOC/LC_MESSAGES
    fi
done

## ============================================= CREATE DIRECTORIES ====

## ==== COPY FILES =====================================================

if [[ $VERBOSE -ge 1 ]]
then
    echo "Copying files..."
fi

# Copy the files
for DIR in bin \
           share/applications \
           share/man/man1 \
           share/crebs/glade \
           share/crebs/lib/crebs
do
    if [[ $VERBOSE -ge 2 ]]
    then
        echo "    $DIR/*..."
    fi
    cp crebs/$DIR/* $PREFIX/$DIR/
done

### Copy the localisation files
for LOC in cs cy de en_GB es it lt ro ru uk
do
    if [[ $VERBOSE -ge 2 ]]
    then
        echo "    $LOC_DIR/$LOC/LC_MESSAGES/*..."
    fi
    cp crebs/$LOC_DIR/$LOC/LC_MESSAGES/* $PREFIX/$LOC_DIR/$LOC/LC_MESSAGES/
done

## ===================================================== COPY FILES ====

## ==== REMOVE FILES ===================================================

if [[ $VERBOSE -ge 1 ]]
then
    echo "Removing old files..."
fi

# Copy the files
for OLD_FILE in share/crebs/lib/crebs/conf.py \
                share/crebs/lib/crebs/conf.pyc \
                share/crebs/lib/crebs/defaults.py \
                share/crebs/lib/crebs/defaults.pyc \
                share/crebs/lib/crebs/files.py \
                share/crebs/lib/crebs/files.pyc \
                share/crebs/lib/crebs/info.py \
                share/crebs/lib/crebs/info.pyc

do
    if [[ $VERBOSE -ge 2 ]]
    then
        echo "    $OLD_FILE..."
    fi
    if [[ -e $PREFIX/$OLD_FILE ]]
    then
        rm $PREFIX/$OLD_FILE
    fi
done

## =================================================== REMOVE FILES ====

## ==== REGISTER APPLICATION ===========================================

if [[ $VERBOSE -ge 1 ]]
then
    echo "Updating desktop database..."
fi

# Register CreBS as an application for its MIME types
update-desktop-database

## =========================================== REGISTER APPLICATION ====

if [[ $VERBOSE -ge 1 ]]
then
    echo "Finished."
fi
